function r4=ICC(X,Y)

%r = ICC(X,Y)
%
%Calculates the inter-class correlation coefficient between X and Y
%X and Y must be the same size


%check inputs
if (nargin <2)
    error('Error. At least two variables needed.');
end

sizeX=size(X);
sizeY=size(Y);
sizesizeY=length(sizeY);
sizesizeX=length(sizeX);

if (sizesizeX ~= sizesizeY)
    error('Error. X and Y must have the same number of dimensions');
end

if (sum(sizeX==sizeY)~=sizesizeX)
    error('Error. X and Y must be the same size');
end

N=numel(X);
X=reshape(X,[N 1]);
Y=reshape(Y,[N 1]);

SX2=sum(X.^2);
SY2=sum(Y.^2);
SXY=sum(X.*Y);
SX=sum(X);
SY=sum(Y);

MSb=(0.5*(SX2+2*SXY+SY2)-(SX+SY).^2/(2*N))/(N-1);
MSw=(0.5*(SX2+SY2)-SXY)/N;

%r1=(MSb-MSw)/(MSb+MSw)  %according to Bishop 2005 - same as SPSS
%r2=(2*(N-1)*SXY-(SX2+SY2))/((N-1)*(SX2+SY2)-2*SXY)  %according to MacArthur 2004
%r2=(2*N*SXY-(SX2+SY2+2*SXY))/(N*(SX2+SY2)-(SX2+SY2+2*SXY))


%{
%according to wikipedia
mu=(SY+SX)/2/N;
S=(SX2+SY2-2*N*mu^2)/(2*N-1);

r3=(SXY-N*mu^2)/S/(N-1)   
S=sum((X-mu).^2+(Y-mu).^2)/(2*N-1);
r=sum((X-mu).*(Y-mu))/(N-1)/S;
%}

%according to McArthur Bishop 2004


%taken from a tutorial that is what SPSS uses for its ICC(1,1)
%a one way random effects
%
totalAverage=(SY+SX)/2/N;

%sum squared between (samples): How much each pair of scores deviates from the grand
%average
%SSb=sum(((X+Y)/2-totalAverage).^2);
%SSb=0.25*sum((X+Y-2*totalAverage).^2);
%SSb=0.25*sum(X.^2+Y.^2-4*totalAverage^2 + 2*X.*Y);
SSb=0.25*(SX2+SY2+2*SXY-4*N*totalAverage^2);    %simplified

%sum squared within (samples): How much pairs differ from eachother.
%SSw=sum((X-Y).^2)/2;
SSw=(SX2+SY2-2*SXY)/2;
MSb=SSb/(N-1);
MSw=SSw/(2*N);  %wikipedia suggests this should be 2*N-1

%look at the difference of between minus within. If the variances from
%sample pair to sample pair is much greater than the variance within a
%sample pair, then the lines are well correlated
r4=(MSb-MSw)/(MSb+MSw);