% -------------------------------------------------------------------------
% INSTITUTE    : University of Western Ontario
% FILENAME     : find_folder_file.m 
% FILE TYPE    : Function
% VERSION      : 1.0
% AUTHOR       : Anthony Bertone
% -------------------------------------------------------------------------
% REVISION HISTORY
% -------------------------------------------------------------------------
% 
%  1.0, 2014-08-05, Anthony Bertone (anthony.m.bertone@gmail.com)
% %    - Initial Release
%
% -------------------------------------------------------------------------
% DESCRIPTION
% -------------------------------------------------------------------------
% 
%  Open age_ICC_subjectList.txt, copy filenames into structure. Folder & 
%  file position will be determined and stored in the structure. 
%  raw_foldername contains all folder names located in directory 
%  'MATLAB_DATA/age_ICC'. raw_filename contains all filenames located 
%  within each age group folder.
%
% -------------------------------------------------------------------------
% -------------------------------------------------------------------------
% -------------------------------------------------------------------------

function S = find_folder_file(data_path, subjects_file_path, subjects_file)

    fid = fopen(subjects_file_path);
    
    % Check if file exists
    if (fid == -1)
        error(['File "' subjects_file '" does not exist.']);
    end
    
    if all(fgetl(fid) == -1)
        error(['File "' subjects_file '" is empty.']); % Error if txt file is empty
    else 
        xx = 0; 
        fseek(fid, 0, 'bof'); % move to the beginning of the txt file
        while ~feof(fid)
            filename = fgetl(fid); 
            if ~isempty(filename)       % check for empty space with text file
                xx = xx + 1;
                S.patient(xx).filename = filename;  % store txt file names in struct
                checker{xx} = filename;             % store filenames in cell array for duplicate check
            end
        end
    end
    fclose('all');
    
    % check if duplicate file names exist with txt file
    if(length(S.patient) > length(unique(checker)))
        error(['Duplicate file names within "' subjects_file '"']); 
    end

    % store age group folder names to struct
    all_folders = dir(data_path);   
    S.raw_foldername = {all_folders([all_folders(:).isdir]).name}';  % cell array of all folder names 
    S.raw_foldername(ismember(S.raw_foldername,{'.','..'})) = [];    % remove '.' folders in cell array

    % store .raw file names in each age group folder to struct   
    for xx = 1:numel(S.raw_foldername)  
        files = dir( fullfile(data_path, char(S.raw_foldername{xx,1}),'*.raw'));
        S.raw_filename{xx,1} = transpose({files.name}); 
    end
    
    % determine folder and position within the folder
    count = 0;
    for xx = 1:numel(S.patient)
        for yy = 1:numel(S.raw_foldername)
            for zz = 1:numel( S.raw_filename{yy,1}) 
                if (strcmp(S.patient(xx).filename, S.raw_filename{yy,1}{zz,1}))
                    count = count + 1;
                    S.patient(xx).folder = yy;  % folder position within age_ICC folder
                    S.patient(xx).pos = zz;     % file position within age group folder
                end
            end
        end
    end
        
    if(count < numel(S.patient))
        error('File is missing from age group folder'); 
    end
    
end



