% -------------------------------------------------------------------------
% INSTITUTE    : University of Western Ontario
% FILENAME     : grandaverage.m 
% FILE TYPE    : Function
% VERSION      : 1.0
% AUTHOR       : Anthony Bertone
% -------------------------------------------------------------------------
% REVISION HISTORY
% -------------------------------------------------------------------------
% 
%  1.0, 2014-08-05, Anthony Bertone (anthony.m.bertone@gmail.com)
%    - Initial Release
%
% -------------------------------------------------------------------------
% DESCRIPTION
% -------------------------------------------------------------------------
%
%  Extract each participant from corresponding age group and calculate  
%  grand average. 
%
% -------------------------------------------------------------------------
% -------------------------------------------------------------------------
% -------------------------------------------------------------------------

function G = grandaverage( S, data_path, channel_names, time0_code, byte_swap )
    
    [row, column] = size(S.patient(1, 1).data.segment.channelData);
    
    for xx = 1:length(S.raw_foldername)
    
        % Create Grand Average titles
        age_group = regexp(S.raw_foldername{xx,1}, '\d+', 'match'); % extract number in age folder title
        if (isempty(age_group))
             error(['Ensure age group folder  "' S.raw_foldername{xx,1} '" contains a numerical age within the title.']);
        else
            G.title{xx} = char( strcat('GTone', age_group) );
        end
    end
    
    % Calculate Grand Average
    for zz = 1: length(S.patient)
    
        for xx = 1:length(S.raw_foldername)

            % Initialize grand average cell array
            % GA = SUM/count
            SUM = single(zeros(row, column));
            count = 0;

            cd(fullfile(data_path, char(S.raw_foldername{xx, 1}))) ;

            for i=1:numel(S.raw_filename{xx,1})
                 if(~strcmp({S.patient(zz).filename}, S.raw_filename{xx, 1}{i,1}))
                    count = count + 1;
                    extract.data  = read_egi_simple_bin(char(S.raw_filename{xx, 1}{i,1}),byte_swap,channel_names,time0_code);
                    SUM = SUM + extract.data.segment.channelData ;                  
                    G(zz).average{xx} = SUM/count;
                 end
            end
            
        end
    end
  
end
 
