% -------------------------------------------------------------------------
% INSTITUTE    : University of Western Ontario
% FILENAME     : runiccanalysis.m 
% FILE TYPE    : Script
% VERSION      : 2.0
% AUTHOR       : Anthony Bertone
% -------------------------------------------------------------------------
% REVISION HISTORY
% -------------------------------------------------------------------------
% 
%  1.0, 2010-09, Drew Morris (drew.j.morris@gmail.com)
%    - Initial release
%  2.0, 2014-08-05, Anthony Bertone (anthony.m.bertone@gmail.com)
%   - Modified Version
%
% -------------------------------------------------------------------------
% DESCRIPTION
% -------------------------------------------------------------------------
%
% Runs intra-class correlation (ICC) coefficient analysis of ERP data
% files.  Files should be in EGI simple binary format (.raw)
%
% -------------------------------------------------------------------------
% -------------------------------------------------------------------------
% -------------------------------------------------------------------------

disp(' ')

loadIccVariables;


try
    checkVariables;
catch e
    disp(['ERROR! ' e.message]);
    return;
end

%now add the paths to make file names fully specified
%full path to output files
ICC_table_file_path=fullfile(output_path, ICC_table_file);

%full path to config files

base_category_file=fullfile(config_path, base_category_file);
subjects_file_path=fullfile(config_path, subjects_file);
channels_to_analyze_file=fullfile(config_path, channels_to_analyze_file);
channel_names_file=fullfile(config_path, channel_names_file);
window_file=fullfile(config_path,window_file);
reference_file=fullfile(config_path, reference_file);


addpath(code_path);
cd(data_path);

%This file has the names for the 128 channel net. You can replace with
%another file that has the names of all the channels, 1 per line
try
    channel_names = read_channel_names(channel_names_file);
catch e
    disp(['ERROR! ' e.message]);
    return;
end


 % Read age group folders and filenames
try
    part_info = find_folder_file(data_path, subjects_file_path, subjects_file );
catch e
    disp(['ERROR! Searching for participant file. ' e.message]);
    return;
end


% Extract .raw file data into structure
try
    part_info = extract_data(part_info, data_path, channel_names, time0_code, byte_swap);
catch e
    disp(['ERROR! Extracting data. ' e.message]);
    return
end


% Calculate the grand average.
try
    GA = grandaverage(part_info, data_path, channel_names, time0_code, byte_swap);
catch e
    disp(['ERROR! Generating Grand Average. ' e.message]);
    return
end

% This reads in a list of channels you wish to include in the analysis
try
    selected_channels = readSelectedChannels(channels_to_analyze_file, channel_names);
catch e
    disp(['ERROR! In reading selected channels. ' e.message]);
    return
end

% This reads in the "base category" for ICC
try
    base_category = readBaseCategory(base_category_file);   % Tone
catch e
    disp(['ERROR reading base category: ' e.message]);
end
 
try
    win = readWindow(window_file);
catch e
    disp(['ERROR! ' e.message]);
    return
end

cd(code_path);

 for ch = 1:numel(part_info.patient)

    try
        [datablock, data_labels, comparison_labels] = createIccDataMatrix(part_info, GA, ch, selected_channels, base_category, win(1),win(2));
    catch e
        disp(['ERROR creating data matrix: ' e.message]);
        return
    end
    
    ICCTABLE{ch} = do_ICC(datablock);
    
    str_ICC_table{ch} = ICCExcelTable(ICCTABLE{ch}, data_labels, comparison_labels);
    
    prompt_ICC_display(str_ICC_table{ch});
 
 end
 
 complete_ICC_table = vertcat(str_ICC_table{:});  % combine all ICC cell arrays into one cell array

 
  try
      save_ICC_table(complete_ICC_table, ICC_table_file_path);
  catch e
      disp(['ERROR saving ICC table: ' e.message]);
      return
  end

  complete_ICC_table = [];
  